@@ -3,6 +3,7 @@ import yaml
 import requests
 import os
 import configparser
+import time
 
 def orchestrate(filename):
     # Load the API key and secret from the configuration file
@@ -65,11 +66,11 @@ def listen(job_id):
         status = res["status"]
         events = res["events"]
         for event in events:
-            print(f"{event['message']}\n")
+            print(f"{event}\n")
         # keep listening for events
         first_time_queued = True
+        total_events = len(events)
         while status != "completed":
-            total_events = len(events)
             # wait five seconds before polling for more events
             time.sleep(5)
             # check for new events
@@ -83,8 +84,9 @@ def listen(job_id):
             events = res["events"]
             if status == "pending":
                 if len(events) > total_events:
-                    for event in events[(total_events+1):]:
-                        print(f"{event['message']}\n")
+                    for event in events[total_events:]:
+                        print(f"{event}\n")
+                    total_events = len(events)
             if status == "queued":
                 if first_time_queued:
                     print("Orchestration job is queued. Waiting for it to start...")
